@@ -49,10 +49,17 @@ class TouchAction(object):
 
         return self
 
-    def press(self, el=None, x=None, y=None):
+    def press(self, el=None, x=None, y=None, pressure=None):
         """Begin a chain with a press down action at a particular element or point
+
+        :Args:
+        - el - (optional) the element to press
+        - x - (optional) x coordiate to press. If y is used, x must also be set
+        - y - (optional) y coordiate to press. If x is used, y must also be set
+        - pressure - (optional) [iOS Only] press as force touch. Read the description of `force` property on Apple's UITouch class
+                                (https://developer.apple.com/documentation/uikit/uitouch?language=objc) for more details on possible value ranges.
         """
-        self._add_action('press', self._get_opts(el, x, y))
+        self._add_action('press', self._get_opts(el, x, y, pressure=pressure))
 
         return self
 
@@ -114,7 +121,7 @@ class TouchAction(object):
         }
         self._actions.append(gesture)
 
-    def _get_opts(self, element, x, y, duration=None):
+    def _get_opts(self, element, x, y, duration=None, pressure=None):
         opts = {}
         if element is not None:
             opts['element'] = element.id
@@ -127,4 +134,7 @@ class TouchAction(object):
         if duration is not None:
             opts['duration'] = duration
 
+        if pressure is not None:
+            opts['pressure'] = pressure
+
         return opts
